.. _driver:

Driver
======

Base
----

.. autoclass:: molecule.driver.basedriver.InvalidDriverSpecified
   :members:

.. autoclass:: molecule.driver.basedriver.InvalidProviderSpecified
   :members:

.. autoclass:: molecule.driver.basedriver.InvalidPlatformSpecified
   :members:

.. autoclass:: molecule.driver.basedriver.BaseDriver
   :members:

Docker
------

.. autoclass:: molecule.driver.dockerdriver.DockerDriver
   :members:

Openstack
---------

.. autoclass:: molecule.driver.openstackdriver.OpenstackDriver
   :members:

Vagrant
-------

.. autoclass:: molecule.driver.vagrantdriver.VagrantDriver
   :members:

